@@ -9,7 +9,6 @@ import copy
 import typing as t
 
 import structlog
-from typing_extensions import Final
 
 import cg_maybe
 
@@ -17,7 +16,7 @@ from ._utils import T_COV as _T_COV
 from ._utils import USE_SLOTS as _USE_SLOTS
 from ._utils import T as _T
 from ._utils import Y as _Y
-from ._utils import type_to_name
+from ._utils import Final, type_to_name
 from .exceptions import ParseError, SimpleParseError, MultipleParseErrors
 from ._swagger_utils import Schema as _Schema
 from ._swagger_utils import OpenAPISchema as _OpenAPISchema
@@ -55,7 +54,7 @@ class Parser(t.Generic[_T_COV]):
 
     def __init__(self) -> None:
         self.__description: Final[t.Optional[str]] = None
-        self.__schema_name: Final[t.Optional[str]] = None
+        self.__schema_name: Final[t.Optional[t.Tuple[str, object]]] = None
         self._use_readable_describe: Final[bool] = False
         self.__open_api_metadata: Final[t.Optional[t.Mapping[str,
                                                              object]]] = None
@@ -89,15 +88,17 @@ class Parser(t.Generic[_T_COV]):
         res.__description = description  # type: ignore[misc]
         return res
 
-    def as_schema(self: _ParserT, name: str) -> _ParserT:
+    def as_schema(self: _ParserT, name: str, typ: object = None) -> _ParserT:
         """Add this parser as a separate model to the OpenAPI spec.
 
         :param name: The name of the model in the spec.
         """
+        if typ is None:
+            typ = object()
         res = copy.copy(self)
         # We cannot assign to this property normally as it is final.
         # pylint: disable=protected-access,unused-private-member
-        res.__schema_name = name  # type: ignore[misc]
+        res.__schema_name = (name, typ)  # type: ignore[misc]
         return res
 
     def add_open_api_metadata(
@@ -169,7 +170,8 @@ class Parser(t.Generic[_T_COV]):
         if self.__schema_name is None:
             return res
         else:
-            return schema.add_as_schema(self.__schema_name, res, object())
+            name, typ = self.__schema_name
+            return schema.add_as_schema(name, res, typ)
 
     def __or__(
         self: 'Parser[_T]', other: 'Parser[_Y]'
@@ -255,6 +257,9 @@ class Union(t.Generic[_T, _Y], Parser[t.Union[_T, _Y]]):
 
     def __init__(self, first: Parser[_T], second: Parser[_Y]) -> None:
         super().__init__()
+        from ._mapping import \
+            DiscriminatedUnion  # pylint: disable=import-outside-toplevel
+
         self._parser: Parser[t.Union[_T, _Y]]
         if isinstance(first, Union):
             first = first._parser
@@ -262,7 +267,11 @@ class Union(t.Generic[_T, _Y], Parser[t.Union[_T, _Y]]):
         if isinstance(second, Union):
             second = second._parser
 
-        if (
+        sub_parsers: t.Sequence[Parser[t.Union[_T, _Y]]] = (first, second)
+        maybe_parser = DiscriminatedUnion.maybe_create(sub_parsers)
+        if maybe_parser.is_just:
+            self._parser = maybe_parser.value
+        elif (
             isinstance(first, SimpleValueFactory) and
             isinstance(second, SimpleValueFactory)
         ):
@@ -283,7 +292,14 @@ class Union(t.Generic[_T, _Y], Parser[t.Union[_T, _Y]]):
         ):
             self._parser = _SimpleUnion(*first.typs, *second.typs)
         else:
-            self._parser = _RichUnion(first, second)
+            parser: cg_maybe.Maybe[Parser[t.Union[_T, _Y]]] = cg_maybe.Nothing
+            if isinstance(first, DiscriminatedUnion):
+                parser = first.maybe_add(second)
+            elif isinstance(second, DiscriminatedUnion):
+                parser = second.maybe_add(first)
+            self._parser = parser.or_default_lazy(
+                lambda: _RichUnion(first, second)
+            )
 
     def describe(self) -> str:
         return self._parser.describe()
