@@ -3,7 +3,7 @@
 import enum
 import typing as t
 
-from ._base import Parser
+from ._base import Parser, SimpleValue
 from ._utils import USE_SLOTS as _USE_SLOTS
 from ._utils import T as _T
 from ._utils import type_to_name as _type_to_name
@@ -19,11 +19,14 @@ class StringEnum(t.Generic[_T], Parser[_T]):
     """A parser for an list of allowed literal string values.
     """
     if _USE_SLOTS:
-        __slots__ = ('opts', )
+        __slots__ = ('opts', 'str_parser')
 
-    def __init__(self, *opts: str) -> None:
+    def __init__(
+        self, *opts: str, str_parser: Parser[str] = SimpleValue.str
+    ) -> None:
         super().__init__()
         self.opts: t.Final[t.FrozenSet[str]] = frozenset(opts)
+        self.str_parser = str_parser
 
     def describe(self) -> str:
         return 'Enum[{}]'.format(', '.join(map(repr, sorted(self.opts))))
@@ -35,19 +38,8 @@ class StringEnum(t.Generic[_T], Parser[_T]):
         }
 
     def try_parse(self, value: object) -> _T:
-        if not isinstance(value, str):
-            raise SimpleParseError(
-                self,
-                value,
-                extra={
-                    'message':
-                        'which is of type {}, not string'.format(
-                            _type_to_name(type(value))
-                        )
-                }
-            )
-
-        if value not in self.opts:
+        str_val = self.str_parser.try_parse(value)
+        if str_val not in self.opts:
             raise SimpleParseError(self, value)
         return t.cast(_T, value)
 
