@@ -10,10 +10,14 @@ from . import (
     file,
     git_provider,
     group,
+    group_set,
     login_link,
     lti,
+    notification,
     oauth_provider,
+    oauth_token,
     permission,
+    plagiarism,
     site_settings,
     snippet,
     submission,
