@@ -25,6 +25,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
         CourseRoleAsJSONWithPerms,
     )
     from ..models.course_snippet import CourseSnippet
+    from ..models.course_statistics_as_json import CourseStatisticsAsJSON
     from ..models.create_assignment_course_data import (
         CreateAssignmentCourseData,
     )
@@ -1034,6 +1035,56 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_statistics(
+        self: "CourseService[codegrade.client.AuthenticatedClient]",
+        *,
+        course_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "CourseStatisticsAsJSON":
+        """Get user statistics of a specific course.
+
+        :param course_id: The id of the course for which you want to get the
+            statistics
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A response containing the course management statistics
+        """
+
+        url = "/api/v1/courses/{courseId}/statistics".format(
+            courseId=course_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.course_statistics_as_json import (
+                CourseStatisticsAsJSON,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(CourseStatisticsAsJSON)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_permissions(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
