@@ -14,6 +14,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     import codegrade
 
     from ..models.create_tenant_data import CreateTenantData
+    from ..models.extended_course import ExtendedCourse
     from ..models.extended_tenant import ExtendedTenant
     from ..models.lti_provider_base import LTIProviderBase
     from ..models.partial_all_site_settings import PartialAllSiteSettings
@@ -337,6 +338,51 @@ class TenantService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_courses(
+        self: "TenantService[codegrade.client.AuthenticatedClient]",
+        *,
+        tenant_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[ExtendedCourse]":
+        """Get the courses for this tenant.
+
+        :param tenant_id: The tenant for which to get the courses.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The courses for this tenant.
+        """
+
+        url = "/api/v1/tenants/{tenantId}/courses/".format(tenantId=tenant_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.extended_course import ExtendedCourse
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(parsers.ParserFor.make(ExtendedCourse))
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_logo(
         self,
         *,
