@@ -43,6 +43,9 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from codegrade._api.oauth_provider import (
         OAuthProviderService as _OAuthProviderService,
     )
+    from codegrade._api.oauth_token import (
+        OAuthTokenService as _OAuthTokenService,
+    )
     from codegrade._api.permission import (
         PermissionService as _PermissionService,
     )
@@ -87,6 +90,7 @@ class _BaseClient:
         "__lti",
         "__notification",
         "__oauth_provider",
+        "__oauth_token",
         "__permission",
         "__plagiarism",
         "__site_settings",
@@ -131,6 +135,9 @@ class _BaseClient:
         self.__oauth_provider: t.Optional[
             "_OAuthProviderService[_BaseClientT]"
         ] = None
+        self.__oauth_token: t.Optional[
+            "_OAuthTokenService[_BaseClientT]"
+        ] = None
         self.__permission: t.Optional[
             "_PermissionService[_BaseClientT]"
         ] = None
@@ -334,6 +341,17 @@ class _BaseClient:
             self.__oauth_provider = m.OAuthProviderService(self)
         return self.__oauth_provider
 
+    @property
+    def oauth_token(self: _BaseClientT) -> "_OAuthTokenService[_BaseClientT]":
+        """Get a :class:`.OAuthTokenService` to do requests concerning
+        OAuthToken.
+        """
+        if self.__oauth_token is None:
+            import codegrade._api.oauth_token as m
+
+            self.__oauth_token = m.OAuthTokenService(self)
+        return self.__oauth_token
+
     @property
     def permission(self: _BaseClientT) -> "_PermissionService[_BaseClientT]":
         """Get a :class:`.PermissionService` to do requests concerning
