@@ -170,6 +170,7 @@ from .course_role import CourseRole
 from .course_role_as_json_with_perms import CourseRoleAsJSONWithPerms
 from .course_snippet import CourseSnippet
 from .course_state import CourseState
+from .course_statistics_as_json import CourseStatisticsAsJSON
 from .create_assignment_course_data import CreateAssignmentCourseData
 from .create_auto_test_data import CreateAutoTestData
 from .create_comment_data import CreateCommentData
@@ -243,6 +244,7 @@ from .general_feedback_comment_base_with_extended_replies import (
 from .general_feedback_extra import GeneralFeedbackExtra
 from .git_repositories_page import GitRepositoriesPage
 from .git_repository_like import GitRepositoryLike
+from .git_user_info import GitUserInfo
 from .global_perm_map import GlobalPermMap
 from .global_permission import GlobalPermission
 from .grade_history import GradeHistory
@@ -378,6 +380,9 @@ from .patch_notification_data import PatchNotificationData
 from .patch_notification_setting_user_setting_data import (
     PatchNotificationSettingUserSettingData,
 )
+from .patch_rubric_category_type_assignment_data import (
+    PatchRubricCategoryTypeAssignmentData,
+)
 from .patch_rubric_result_submission_data import (
     PatchRubricResultSubmissionData,
 )
@@ -402,6 +407,7 @@ from .plagiarism_run_plagiarism_course_as_json import (
     PlagiarismRunPlagiarismCourseAsJSON,
 )
 from .plagiarism_state import PlagiarismState
+from .post_oauth_token_data import PostOAuthTokenData
 from .present_preference import PresentPreference
 from .proxy import Proxy
 from .put_enroll_link_course_data import PutEnrollLinkCourseData
