@@ -17,7 +17,7 @@ class BaseLTI1p1Provider(BaseLTIProvider):
     """The base JSON representation of a LTI 1.1 provider."""
 
     #: The LMS that is connected as this LTI provider.
-    lms: "t.Literal['Blackboard', 'BrightSpace', 'Canvas', 'Moodle', 'Open edX', 'Populi', 'Sakai']"
+    lms: "t.Literal['Blackboard', 'BrightSpace', 'Canvas', 'Moodle', 'Open edX', 'Populi', 'Sakai', 'Thought Industries']"
     #: The LTI version used.
     version: "t.Literal['lti1.1']"
     #: Can you set the `lock_date` of assignment connected to this LTI
@@ -39,6 +39,7 @@ class BaseLTI1p1Provider(BaseLTIProvider):
                         "Open edX",
                         "Populi",
                         "Sakai",
+                        "Thought Industries",
                     ),
                     doc="The LMS that is connected as this LTI provider.",
                 ),
