@@ -30,7 +30,7 @@ class CoursePermMap:
     #: Users with this permission can grade submissions.
     can_grade_work: "bool"
     #: Users with this permission can see the grade for a submission before an
-    #: assignment is set to "done".
+    #: assignment is set to "Done".
     can_see_grade_before_open: "bool"
     #: Users with this permission can see submissions of other users of this
     #: course.
@@ -38,7 +38,7 @@ class CoursePermMap:
     #: Users with this permission can view the assignments of this course.
     can_see_assignments: "bool"
     #: Users with this permission can view assignments of this course that are
-    #: set to "hidden".
+    #: set to "Hidden".
     can_see_hidden_assignments: "bool"
     #: Users with this permission can update the assignment info such as name,
     #: deadline and status.
@@ -63,7 +63,7 @@ class CoursePermMap:
     #: Users with this permission can submit their work after the deadline of
     #: an assignment.
     can_upload_after_deadline: "bool"
-    #: Users with this permission can see who is assigned to assess a
+    #: Users with this permission can see which grader is assigned to assess a
     #: submission.
     can_see_assignee: "bool"
     #: Users with this permission can update the rubrics for the assignments of
@@ -90,7 +90,7 @@ class CoursePermMap:
     #: Users with this permission can view the summary of a plagiarism check
     #: and see details of a plagiarism case. To view a plagiarism case between
     #: this and another course, the user must also have either this permission,
-    #: or both "See assignments" and "See other's work" in the other course.
+    #: or both "View assignments" and "View other's work" in the other course.
     can_view_plagiarism: "bool"
     #: Users with this permission can add and delete plagiarism runs.
     can_manage_plagiarism: "bool"
@@ -139,7 +139,7 @@ class CoursePermMap:
     #: the permission to view the summary of this step
     can_view_hidden_autotest_steps: "bool"
     #: Users with this permission can view AutoTest, such as sets, before the
-    #: state of the assignment is "Open"
+    #: state of the assignment is "Done"
     can_view_autotest_before_done: "bool"
     #: Users with this permission are allowed to see the details of non hidden
     #: AutoTest steps
@@ -148,19 +148,19 @@ class CoursePermMap:
     #: fixtures
     can_view_autotest_fixture: "bool"
     #: Users with this permission can view output files created during an
-    #: AutoTest before the assignment state is "done"
+    #: AutoTest before the assignment state is "Done"
     can_view_autotest_output_files_before_done: "bool"
     #: Users with this permission can delete assignments within this course.
     can_delete_assignments: "bool"
     #: Users with this permission can create new submissions, even if the
-    #: maximum amount of submissions has been reacher, or if a cool-off period
+    #: maximum number of submissions has been reached, or if a cool-off period
     #: is in effect.
     can_override_submission_limiting: "bool"
     #: Users with this permission can see the output of linters before an
-    #: assignment is set to "done"
+    #: assignment is set to "Done"
     can_see_linter_feedback_before_done: "bool"
     #: Users with this permission can see all inline and general feedback,
-    #: except for peer feedback, before an assignment is set to "done"
+    #: except for peer feedback, before an assignment is set to "Done"
     can_see_user_feedback_before_done: "bool"
     #: Users with this permission can view the analytics dashboard of an
     #: assignment.
@@ -175,7 +175,7 @@ class CoursePermMap:
     #: general comments placed by others
     can_view_others_comment_edits: "bool"
     #: Users with this permission can view the author of inline and general
-    #: feedback
+    #: feedback.
     can_view_feedback_author: "bool"
     #: Users with this permission can email students using the contact student
     #: button.
@@ -185,8 +185,8 @@ class CoursePermMap:
     #: Users still need to have the permission to see the feedback, so this
     #: permission alone is not enough to see peer feedback.
     can_view_inline_feedback_before_approved: "bool"
-    #: Users with this permission can approve inline and general comments,
-    #: comments that need approval include peer feedback comments.
+    #: Users with this permission can approve inline and general comments.
+    #: Comments that need approval include peer feedback comments.
     can_approve_inline_comments: "bool"
     #: Users with this permission can edit the peer feedback status of an
     #: assignment.
@@ -195,22 +195,22 @@ class CoursePermMap:
     #: for the assignment. You should not give this permission to users with
     #: powerful permissions (such as "Can grade work").
     can_receive_login_links: "bool"
-    #: Users will be able to see a course that is archived. Users that do not
-    #: have this permission will not be able to see any data (e.g. submissions)
-    #: connected to an archived course.
+    #: Users with this permission can see a course that is archived. Users that
+    #: do not have this permission will not be able to see any data (e.g.
+    #: submissions) connected to an archived course.
     can_see_archived_courses: "bool"
-    #: Users will be able to archive courses. After archiving a course users
-    #: that do not have the "See archived courses" permission will no longer be
-    #: able too see the course.
+    #: Users with this permission can archive courses. After archiving a course
+    #: users that do not have the "View archived courses" permission will no
+    #: longer be able too see the course.
     can_archive_courses: "bool"
     #: Users with this permission can edit general information of a course, for
     #: example the name.
     can_edit_course_info: "bool"
-    #: Users with this permission can still upload (submit) work after the lock
+    #: Users with this permission can still submit their work after the lock
     #: date of an assignment.
     can_upload_after_lock_date: "bool"
     #: Users with this permission are allowed to see inline and general peer
-    #: feedback before the state of an assignment has been set to "done".
+    #: feedback before the state of an assignment has been set to "Done".
     can_see_peer_feedback_before_done: "bool"
     #: Users with this permission can see the real name of students even when
     #: anonymized grading is enabled.
@@ -218,6 +218,10 @@ class CoursePermMap:
     #: Users with this permission can view AutoTest results of other users they
     #: are peer reviewing.
     can_view_peer_review_autotest_results: "bool"
+    #: Users with this permission can submit their work for group assignments
+    #: without being member of a group or when their group does not meet the
+    #: minimum size requirements.
+    can_upload_without_group: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -262,7 +266,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can see the grade for a"
-                    ' submission before an assignment is set to "done".'
+                    ' submission before an assignment is set to "Done".'
                 ),
             ),
             rqa.RequiredArgument(
@@ -286,7 +290,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view assignments of this"
-                    ' course that are set to "hidden".'
+                    ' course that are set to "Hidden".'
                 ),
             ),
             rqa.RequiredArgument(
@@ -357,8 +361,8 @@ class CoursePermMap:
                 "can_see_assignee",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can see who is assigned to"
-                    " assess a submission."
+                    "Users with this permission can see which grader is"
+                    " assigned to assess a submission."
                 ),
             ),
             rqa.RequiredArgument(
@@ -425,8 +429,8 @@ class CoursePermMap:
                     " plagiarism check and see details of a plagiarism case."
                     " To view a plagiarism case between this and another"
                     " course, the user must also have either this permission,"
-                    ' or both "See assignments" and "See other\'s work" in the'
-                    " other course."
+                    ' or both "View assignments" and "View other\'s work" in'
+                    " the other course."
                 ),
             ),
             rqa.RequiredArgument(
@@ -566,7 +570,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view AutoTest, such as"
-                    ' sets, before the state of the assignment is "Open"'
+                    ' sets, before the state of the assignment is "Done"'
                 ),
             ),
             rqa.RequiredArgument(
@@ -590,7 +594,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view output files created"
-                    ' during an AutoTest before the assignment state is "done"'
+                    ' during an AutoTest before the assignment state is "Done"'
                 ),
             ),
             rqa.RequiredArgument(
@@ -606,8 +610,8 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can create new submissions,"
-                    " even if the maximum amount of submissions has been"
-                    " reacher, or if a cool-off period is in effect."
+                    " even if the maximum number of submissions has been"
+                    " reached, or if a cool-off period is in effect."
                 ),
             ),
             rqa.RequiredArgument(
@@ -615,7 +619,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can see the output of linters"
-                    ' before an assignment is set to "done"'
+                    ' before an assignment is set to "Done"'
                 ),
             ),
             rqa.RequiredArgument(
@@ -624,7 +628,7 @@ class CoursePermMap:
                 doc=(
                     "Users with this permission can see all inline and general"
                     " feedback, except for peer feedback, before an assignment"
-                    ' is set to "done"'
+                    ' is set to "Done"'
                 ),
             ),
             rqa.RequiredArgument(
@@ -665,7 +669,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view the author of inline"
-                    " and general feedback"
+                    " and general feedback."
                 ),
             ),
             rqa.RequiredArgument(
@@ -692,7 +696,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can approve inline and general"
-                    " comments, comments that need approval include peer"
+                    " comments. Comments that need approval include peer"
                     " feedback comments."
                 ),
             ),
@@ -718,19 +722,20 @@ class CoursePermMap:
                 "can_see_archived_courses",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users will be able to see a course that is archived."
-                    " Users that do not have this permission will not be able"
-                    " to see any data (e.g. submissions) connected to an"
-                    " archived course."
+                    "Users with this permission can see a course that is"
+                    " archived. Users that do not have this permission will"
+                    " not be able to see any data (e.g. submissions) connected"
+                    " to an archived course."
                 ),
             ),
             rqa.RequiredArgument(
                 "can_archive_courses",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users will be able to archive courses. After archiving a"
-                    ' course users that do not have the "See archived courses"'
-                    " permission will no longer be able too see the course."
+                    "Users with this permission can archive courses. After"
+                    ' archiving a course users that do not have the "View'
+                    ' archived courses" permission will no longer be able too'
+                    " see the course."
                 ),
             ),
             rqa.RequiredArgument(
@@ -745,7 +750,7 @@ class CoursePermMap:
                 "can_upload_after_lock_date",
                 rqa.SimpleValue.bool,
                 doc=(
-                    "Users with this permission can still upload (submit) work"
+                    "Users with this permission can still submit their work"
                     " after the lock date of an assignment."
                 ),
             ),
@@ -755,7 +760,7 @@ class CoursePermMap:
                 doc=(
                     "Users with this permission are allowed to see inline and"
                     " general peer feedback before the state of an assignment"
-                    ' has been set to "done".'
+                    ' has been set to "Done".'
                 ),
             ),
             rqa.RequiredArgument(
@@ -774,6 +779,16 @@ class CoursePermMap:
                     " other users they are peer reviewing."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_upload_without_group",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can submit their work for"
+                    " group assignments without being member of a group or"
+                    " when their group does not meet the minimum size"
+                    " requirements."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -893,6 +908,7 @@ class CoursePermMap:
             "can_view_peer_review_autotest_results": to_dict(
                 self.can_view_peer_review_autotest_results
             ),
+            "can_upload_without_group": to_dict(self.can_upload_without_group),
         }
         return res
 
@@ -969,6 +985,7 @@ class CoursePermMap:
             can_see_peer_feedback_before_done=parsed.can_see_peer_feedback_before_done,
             can_see_anonymized_names=parsed.can_see_anonymized_names,
             can_view_peer_review_autotest_results=parsed.can_view_peer_review_autotest_results,
+            can_upload_without_group=parsed.can_upload_without_group,
         )
         res.raw_data = d
         return res
