@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import typing as t
 from dataclasses import dataclass, field
 
@@ -67,3 +68,18 @@ class FinalizedLTI1p3Provider(BaseLTI1p3Provider):
         )
         res.raw_data = d
         return res
+
+
+import os
+
+if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
+    # fmt: off
+    import datetime
+
+    from .base_lti_provider import BaseLTIProvider
+    from .lms_capabilities import LMSCapabilities
+    from .lti1p3_provider_presentation_as_json import (
+        LTI1p3ProviderPresentationAsJSON,
+    )
+
+    # fmt: on
